//=============================================================================
// BMP_Core.js
//=============================================================================

/*:
 * @plugindesc Britney's Core Engine for RPG Maker MV.
 * @author Britney Pringle
 */

var BMP_PLUGIN = BMP_PLUGIN || {};
BMP_PLUGIN.Core = {};
BMP_PLUGIN.Core.Parameters = PluginManager.parameters('BMP_Core');
console.log("BMP_Core is active.");

BMP_PLUGIN.Core.BitmapInitialize = Bitmap.prototype.initialize;
Bitmap.prototype.initialize = function(width, height) {
    BMP_PLUGIN.Core.BitmapInitialize.call(this, width, height);
    //this.outlineColor = 'rgba(0, 0, 0, 0)';
	this.outlineWidth = 4;
}

Input.keyMapper[8] = 'escape'; 	  // Backspace
Input.keyMapper[69] = 'pagedown'; // E
Input.keyMapper[87] = 'up';       // W
Input.keyMapper[65] = 'left';     // A
Input.keyMapper[83] = 'down';     // S
Input.keyMapper[68] = 'right';    // D

SceneManager.snapForBackground = function() {
    this._backgroundBitmap = this.snap();
};

Window_Base.prototype.standardFontSize = function() {
    return 24;
};

Window_Base.prototype.lineHeight = function() {
    return 36;
};

Window_Base.prototype.standardPadding = function() {
    return 16;
};

Window_Base.prototype.textPadding = function() {
    return 6;
};

Window_Base.prototype.standardBackOpacity = function() {
    return 255;
};

Window_Base.prototype.dimColor1 = function() {
    return 'rgba(31, 31, 31, 0.75)';
};

Window_Base.prototype.dimColor2 = function() {
    return 'rgba(31, 31, 31, 0.75)';
};

Window_Base.prototype.hpGaugeColor1 = function() {
    return this.textColor(28);
};

Window_Base.prototype.hpGaugeColor2 = function() {
    return this.textColor(29);
};

Window_Message.prototype.loadWindowskin = function() {
    this.windowskin = ImageManager.loadSystem('Window');
};

Window_Message.prototype.windowWidth = function() {
    return Graphics.boxWidth * 0.75;
};

Window_Message.prototype.numVisibleRows = function() {
    return 2;
};

Window_Message.prototype.updatePlacement = function() {
	var margin = 48;
    this._positionType = $gameMessage.positionType();
    if (this._positionType === 0) {
        this.y = margin;
    } else if (this._positionType === 1) {
        this.y = (Graphics.boxHeight - this.height) / 2;
    } else {
        this.y = Graphics.boxHeight - this.height - margin;
    }
    
    this._goldWindow.y = this.y > 0 ? 0 : Graphics.boxHeight - this._goldWindow.height;
};

Window_ScrollText.prototype.initialize = function() {
    var width = Graphics.boxWidth * 0.5;
    var height = Graphics.boxHeight;
    Window_Base.prototype.initialize.call(this, Graphics.boxWidth * 0.33, 0, width, height);
    this.opacity = 0;
    this.hide();
    this._text = '';
    this._allTextHeight = 0;
};

Window_ChoiceList.prototype.updatePlacement = function() {
    var positionType = $gameMessage.choicePositionType();
    var messageY = this._messageWindow.y;
	var margin = Graphics.boxWidth * 0.125;
    
	this.width = this.windowWidth();
    this.height = this.windowHeight();
    switch (positionType) {
    case 0:
        this.x = margin;
        break;
    case 1:
        this.x = (Graphics.boxWidth - this.width) / 2;
        break;
    case 2:
        this.x = Graphics.boxWidth - this.width - margin;
        break;
    }
    if (messageY >= Graphics.boxHeight / 2) {
        this.y = messageY - this.height;
    } else {
        this.y = messageY + this._messageWindow.height;
    }
};



//-----------------------------------------------------------------------------
// Scene_Menu
//
// The scene class of the menu screen.
Scene_Menu.prototype.create = function() {
    Scene_MenuBase.prototype.create.call(this);
    this.createCommandWindow();
};

Scene_Menu.prototype.start = function() {
    Scene_MenuBase.prototype.start.call(this);
};

Scene_Menu.prototype.createCommandWindow = function() {
    this._commandWindow = new Window_MenuCommand(0, 0);
    this._commandWindow.setHandler('item',      this.commandItem.bind(this));
    this._commandWindow.setHandler('skill',     this.commandPersonal.bind(this));
    this._commandWindow.setHandler('equip',     this.commandPersonal.bind(this));
    this._commandWindow.setHandler('status',    this.commandPersonal.bind(this));
    this._commandWindow.setHandler('formation', this.commandFormation.bind(this));
    this._commandWindow.setHandler('options',   this.commandOptions.bind(this));
    this._commandWindow.setHandler('save',      this.commandSave.bind(this));
    this._commandWindow.setHandler('gameEnd',   this.commandGameEnd.bind(this));
    this._commandWindow.setHandler('cancel',    this.popScene.bind(this));
    this.addWindow(this._commandWindow);
	
	this._commandWindow.x = (Graphics.boxWidth - this._commandWindow.windowWidth()) / 2;
	this._commandWindow.y = (Graphics.boxHeight - this._commandWindow.windowHeight()) / 2;
};

Scene_Menu.prototype.createBackground = function() {
    Scene_MenuBase.prototype.createBackground.call(this);
    this.setBackgroundOpacity(128);
};

Scene_Options.prototype.createBackground = function() {
    Scene_MenuBase.prototype.createBackground.call(this);
    this.setBackgroundOpacity(128);
};